@@ -19,11 +19,9 @@
 #include "analitzawrapper.h"
 #include <analitza/analyzer.h>
 #include <analitza/value.h>
-#include <analitza/variables.h>
 #include <analitza/analitzautils.h>
 #include <analitzagui/variablesmodel.h>
 
-#include <QVariant>
 
 Q_DECLARE_METATYPE(ExpressionWrapper*)
 
